/*
 * $Id: DummyOptions.java 114 2006-09-15 17:19:39Z rasan $
 *
 * Copyright (c) 2002-2006 UC Regents
 * 
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names
 * of the UC Regents and the University of California are not used in any
 * advertising or publicity relating to the software without the specific,
 * prior written permission of the University of California.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE FOR ANY
 * SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY
 * THEORY OF LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE
 * OR PERFORMANCE OF THIS SOFTWARE.
 */

package org.cdl.noid;

/** 
 * DummyOptions implements the Options interface and is used
 * to perform a no-op when asked to parse command line arguments.
 * This is useful on operating systems that do not have a
 * command line.  All of <code>NoidTest</code>'s possible
 * command line args will be set to either false or null.
 * 
 * @author Rasan Rasch (rasan@nyu.edu)
 * @version $Revision: 114 $
 */
public class DummyOptions implements Options {

	/** 
	 * Construct a new DummyOptions o
	 * 
	 * @param args 
	 */
	public DummyOptions(String[] args) {
		// do nothing
	}

	/** 
	 * Operation not implemented (NOOP).
	 */
	public void parseOptions() {
		// do nothing
	}

	/** 
	 * Always return false.
	 * 
	 * @return <code>false</code>
	 */
	public boolean getDebug() {
		return false;
	}

	/** 
	 * Always return false.
	 * 
	 * @return <code>false</code>
	 */
	public boolean getHelp() {
		return false;
	}

	/** 
	 * Always return false.
	 * 
	 * @return <code>false</code>
	 */
	public boolean getVersion() {
		return false;
	}
	
	/** 
	 * Always return null.
	 * 
	 * @return <code>null</code>
	 */
	public Integer getLocktest() {
		return null;
	}
	
	/** 
	 * Always return null.
	 * 
	 * @return <code>null</code>
	 */
	public String getDbdir() {
		return null;
	}

}
